@@ -2,7 +2,7 @@
 
 /* generate_defs_gda.h
  *
- * Copyright (C) 2001 The Free Software Foundation
+ * Copyright 2006-2008 The maemomm development team
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -21,10 +21,10 @@
 
 #include "glibmm_generate_extra_defs/generate_extra_defs.h"
 
-#include <hildon-widgets/hildon-file-chooser-dialog.h>
-#include <hildon-widgets/hildon-file-selection.h>
-#include <hildon-widgets/hildon-file-system-model.h>
-//#include <hildon-widgets/hildon-file-system-settings.h>
+#include <hildon/hildon-file-chooser-dialog.h>
+#include <hildon/hildon-file-details-dialog.h>
+#include <hildon/hildon-file-selection.h>
+#include <hildon/hildon-file-system-model.h>
 
 #include <gtk/gtk.h>
 
@@ -34,9 +34,9 @@ int main (int argc, char *argv[])
     gtk_init(&argc, &argv);
 
     std::cout << get_defs(HILDON_TYPE_FILE_CHOOSER_DIALOG)
+              << get_defs(HILDON_TYPE_FILE_DETAILS_DIALOG)
               << get_defs(HILDON_TYPE_FILE_SELECTION)
               << get_defs(HILDON_TYPE_FILE_SYSTEM_MODEL)
-              //<< get_defs(HILDON_TYPE_FILE_SYSTEM_SETTINGS)
               << std::endl;
 
     return 0;
